from qwentastic.core import (
    model_init, model_data, model_prompt,
    qwen_init, qwen_data, qwen_prompt  # Aliases for backward compatibility
)

__version__ = "0.2.0"
__all__ = [
    "model_init", "model_data", "model_prompt",
    "qwen_init", "qwen_data", "qwen_prompt"
]
